### 고급 옵션

이 섹션은 이 소프트웨어의 고급 사용자를 위한 것입니다. 여기에서 다음을 찾을 수 있습니다:

1. [**고급 옵션**](./advanced.md)
<br>
이 섹션에서는 특정 소스/대상 언어를 지정하고, 번역 서비스를 전환하는 등의 기능을 탐색할 수 있습니다.

2. [**언어 코드**](./Language-Codes.md)
<br>
소스/대상 언어 번역에 사용할 코드가 확실하지 않은 경우 여기에서 찾을 수 있습니다.

3. [**번역 서비스 문서**](./Documentation-of-Translation-Services.md)
<br>
사용 중인 번역 서비스에서 제공하는 문서를 검토해야 하는 경우 이 페이지를 참조하세요.

<div align="right"> 
<h6><small>이 페이지의 일부 내용은 GPT에 의해 번역되었으며 오류가 포함될 수 있습니다.</small></h6>